@@ -1,20 +1,20 @@
 from nose import with_setup
 
-from yubiauth.model import create_db
-from yubiauth import YubiAuth
+from yubiauth import create_tables
+from yubiauth.core import YubiAuth
 
 from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker
 
 engine = create_engine('sqlite:///:memory:', echo=True)
-create_db(engine)
+create_tables(engine)
 Session = sessionmaker(bind=engine)
 auth = None
 
 
 def setup():
     global auth
-    auth = YubiAuth(Session)
+    auth = YubiAuth(Session())
     teardown()
     auth.create_user('user1', 'p4ssw0rd')
     auth.create_user('user2', 'foo')
